/*
 * Copyright (C) 2007 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.example.android.marslander;

import android.app.Activity;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.TextView;

import com.example.android.marslander.MarsView.MarsThread;

public class MarsLander extends Activity {

    /** A handle to the thread that's actually running the animation. */
    private MarsThread mMarsThread;

    /** A handle to the View in which the game is running. */
    private MarsView mMarsView;

    /**
     * Invoked when the Activity is created.
     *
     * @param savedInstanceState a Bundle containing state saved from a previous
     *        execution, or null if this is a new execution
     */
    @Override
    protected void onCreate(Bundle savedInstanceState) {
    	// super.onCreate(savedInstanceState);
    	super.onCreate(null);

    	// tell system to use the layout defined in our XML file
    	setContentView(R.layout.mars_layout);

    	// get handles to the MarsView from XML, and its MarsThread
    	mMarsView = (MarsView) findViewById(R.id.mars);
    	mMarsThread = mMarsView.getThread();

    	// give the MarsView a handle to the TextView used for messages 
    	// (which is overlaid on top of drawing SurfaceView -- see layout xml)
    	mMarsView.setTextView((TextView) findViewById(R.id.text));

    	// we were just launched: set up a new game
    	mMarsThread.setState(MarsThread.STATE_READY);
    }

    /**
     * Invoked when the Activity loses user focus.
     */
    
    @Override
    protected void onPause() {
    	
        super.onPause();
        //mMarsView.getThread().pause(); // pause game when Activity pauses
        
        finish();   // just die...getting force close on resume otherwise...
    }

}
